@@ -2,7 +2,7 @@ package WebService::ILS;
 
 use Modern::Perl;
 
-our $VERSION = "0.15";
+our $VERSION = "0.16";
 
 =encoding utf-8
 
@@ -203,10 +203,13 @@ __PACKAGE__->_set_param_spec({
 
 sub BUILDARGS {
     my $self = shift;
-    my $params = shift;
+    my $params = shift || {};
+    if (!ref( $params )) {
+        $params = {$params, @_};
+    }
 
     local $Params::Check::WARNINGS_FATAL = 1;
-    my $params = Params::Check::check($self->_get_param_spec, $params)
+    $params = Params::Check::check($self->_get_param_spec, $params)
         or croak "Invalid parameters: ".Params::Check::last_error();
     return $params;
 }
